/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.account.constants;

import com.liferay.account.model.AccountRole;
import com.liferay.account.service.AccountRoleLocalServiceUtil;
import com.liferay.portal.kernel.model.Role;
import com.liferay.portal.kernel.util.ArrayUtil;

import java.util.Objects;

/**
 * @author Drew Brokke
 */
public class AccountRoleConstants {

	public static final String REQUIRED_ROLE_NAME_ACCOUNT_ADMINISTRATOR =
		"Account Administrator";

	public static final String REQUIRED_ROLE_NAME_ACCOUNT_MANAGER =
		"Account Manager";

	public static final String REQUIRED_ROLE_NAME_ACCOUNT_MEMBER =
		"Account Member";

	/**
	 * @deprecated As of Athanasius (7.3.x), replaced by {@link
	 *             #REQUIRED_ROLE_NAME_ACCOUNT_MANAGER}
	 */
	@Deprecated
	public static final String REQUIRED_ROLE_NAME_ACCOUNT_OWNER =
		"Account Owner";

	/**
	 * @deprecated As of Athanasius (7.3.x), replaced by {@link
	 *             #REQUIRED_ROLE_NAME_ACCOUNT_ADMINISTRATOR}
	 */
	@Deprecated
	public static final String REQUIRED_ROLE_NAME_ACCOUNT_POWER_USER =
		"Account Power User";

	/**
	 * @deprecated As of Athanasius (7.3.x), replaced by {@link
	 *             #REQUIRED_ROLE_NAME_ACCOUNT_MEMBER}
	 */
	@Deprecated
	public static final String REQUIRED_ROLE_NAME_ACCOUNT_USER = "Account User";

	public static final String[] REQUIRED_ROLE_NAMES = {
		REQUIRED_ROLE_NAME_ACCOUNT_ADMINISTRATOR,
		REQUIRED_ROLE_NAME_ACCOUNT_MANAGER, REQUIRED_ROLE_NAME_ACCOUNT_MEMBER
	};

	public static boolean isImpliedRole(Role role) {
		if (Objects.equals(REQUIRED_ROLE_NAME_ACCOUNT_MEMBER, role.getName())) {
			return true;
		}

		return false;
	}

	public static boolean isRequiredRole(Role role) {
		return ArrayUtil.contains(REQUIRED_ROLE_NAMES, role.getName());
	}

	public static boolean isSharedRole(Role role) {
		AccountRole accountRole =
			AccountRoleLocalServiceUtil.fetchAccountRoleByRoleId(
				role.getRoleId());

		if (Objects.equals(
				accountRole.getAccountEntryId(),
				AccountConstants.ACCOUNT_ENTRY_ID_DEFAULT)) {

			return true;
		}

		return false;
	}

}