/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.account.exception;

import com.liferay.portal.kernel.exception.PortalException;

/**
 * @author Brian Wing Shun Chan
 */
public class DefaultAccountGroupException extends PortalException {

	public DefaultAccountGroupException() {
	}

	public DefaultAccountGroupException(String msg) {
		super(msg);
	}

	public DefaultAccountGroupException(String msg, Throwable throwable) {
		super(msg, throwable);
	}

	public DefaultAccountGroupException(Throwable throwable) {
		super(throwable);
	}

	public static class MustNotDeleteDefaultAccountGroup
		extends DefaultAccountGroupException {

		public MustNotDeleteDefaultAccountGroup(long accountGroupId) {
			super(
				String.format(
					"The default account group %s cannot be deleted",
					accountGroupId));

			this.accountGroupId = accountGroupId;
		}

		public long accountGroupId;

	}

	public static class MustNotDuplicateDefaultAccountGroup
		extends DefaultAccountGroupException {

		public MustNotDuplicateDefaultAccountGroup(long companyId) {
			super(
				String.format(
					"There is already a default account group for company %s",
					companyId));

			this.companyId = companyId;
		}

		public long companyId;

	}

	public static class MustNotUpdateDefaultAccountGroup
		extends DefaultAccountGroupException {

		public MustNotUpdateDefaultAccountGroup(long accountGroupId) {
			super(
				String.format(
					"The default account group %s cannot be updated",
					accountGroupId));

			this.accountGroupId = accountGroupId;
		}

		public long accountGroupId;

	}

}